# Changelog

## 0.1.0-alpha.5 (2024-12-25)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/mechanixlabs/python-sdk/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** api update ([#22](https://github.com/mechanixlabs/python-sdk/issues/22)) ([3e855bd](https://github.com/mechanixlabs/python-sdk/commit/3e855bd2ed082a5b7072d47cc8407375609e2954))
* **api:** manual updates ([#24](https://github.com/mechanixlabs/python-sdk/issues/24)) ([cc214ed](https://github.com/mechanixlabs/python-sdk/commit/cc214ed429b0ed69857636315611f680b510a891))

## 0.1.0-alpha.4 (2024-12-23)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/mechanixlabs/python-sdk/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** api update ([#17](https://github.com/mechanixlabs/python-sdk/issues/17)) ([278e3bc](https://github.com/mechanixlabs/python-sdk/commit/278e3bc8f57e0fb874f308364caba4feb2f3b09a))
* **api:** manual updates ([#20](https://github.com/mechanixlabs/python-sdk/issues/20)) ([a46fd79](https://github.com/mechanixlabs/python-sdk/commit/a46fd7959b834e5ecbf04bd1fe2d5bbc75f83983))

## 0.1.0-alpha.3 (2024-12-23)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/mechanixlabs/python-sdk/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** manual updates ([#13](https://github.com/mechanixlabs/python-sdk/issues/13)) ([9410b32](https://github.com/mechanixlabs/python-sdk/commit/9410b3280e89a4520c7c07d06cb860b37fca3cc9))

## 0.1.0-alpha.2 (2024-12-23)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/mechanixlabs/python-sdk/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([#9](https://github.com/mechanixlabs/python-sdk/issues/9)) ([c15cd69](https://github.com/mechanixlabs/python-sdk/commit/c15cd69fb9d50b05f65ec704749f923229876e3a))

## 0.1.0-alpha.1 (2024-12-21)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/mechanixlabs/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([#3](https://github.com/mechanixlabs/python-sdk/issues/3)) ([0eaf8c2](https://github.com/mechanixlabs/python-sdk/commit/0eaf8c2de367e7105e56ab307de238be2d87ca44))
* **api:** manual updates ([#4](https://github.com/mechanixlabs/python-sdk/issues/4)) ([6b9a941](https://github.com/mechanixlabs/python-sdk/commit/6b9a941f0f2484e2de425698816ec9143031e52a))
* **api:** shorten README.md ([cf24e13](https://github.com/mechanixlabs/python-sdk/commit/cf24e13bd8488f3fc102384f81d59e577a6691cf))
* **api:** update README.md ([753efe8](https://github.com/mechanixlabs/python-sdk/commit/753efe884611b610b157407eedd6baa3b6ca39cb))
* **api:** update README.md documentation ([689eb2c](https://github.com/mechanixlabs/python-sdk/commit/689eb2cd6645c194c9e4816215a0d526a1d5de7e))
* **api:** update README.md example ([411b310](https://github.com/mechanixlabs/python-sdk/commit/411b31027ff6f0f73dfa5adc95ae7f65bf5a24c1))


### Chores

* go live ([#1](https://github.com/mechanixlabs/python-sdk/issues/1)) ([2fda41d](https://github.com/mechanixlabs/python-sdk/commit/2fda41dccda2772002519bd13757158821d278d2))
